@@ -37,6 +37,12 @@ class ArgParser:
             help="Backup characters file.",
             metavar="BACKUP_TO"
         )
+        self.parser.add_argument(
+            "-s",
+            "--show",
+            help="Show backuped characters.",
+            action='store_true'
+        )
         self.parser.add_argument(
             "-r",
             "--restore",
